...

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlElement;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.hibernate.envers.Audited;
import org.springframework.util.CollectionUtils;
import ...


/**
 * Clase que representa la asignacion de PVA a un modelo de contrato.
 * 
 * @author 
 * @version 1.0.0
 */
@Audited
public class AsignacionPVAMC extends AsignacionPVAModeloContrato {


	/** Serial UID. */
	private static final long serialVersionUID = - 2671890094628571093L;

	// Modelo de contrato.
	@XmlElement ( name = "mc" )
	private ModeloContrato modeloContrato;

	/**
	 * @return the modeloContrato
	 */
	public ModeloContrato getModeloContrato() {
		return modeloContrato;
	}

	/**
	 * @param modeloContrato
	 *            the modeloContrato to set
	 */
	public void setModeloContrato( ModeloContrato modeloContrato ) {
		this.modeloContrato = modeloContrato;
	}

	/**
	 * @return la {@link PrestacionVarianteAmbitoBid} equivalente a la asignacion.
	 */
	public PrestacionVarianteAmbitoBid getPVAmbitoBid() {

		// TODO revisar durante el desarrollo si se usa.

		Ambito a = getAsignacionPVA().getAmbito();
		// VariantePrestacion vp = getAsignacionPVA().getVariantePrestacion();
		VariantePrestacionResumenDTO vp = getAsignacionPVA().getVariantePrestacion();
		PrestacionResumenDTO p = vp.getPrestacionPadre();

		PrestacionVarianteAmbitoBid pvaBid = new PrestacionVarianteAmbitoBid();

		pvaBid.setCodigoCapitulo( p.getCapitulo().getCodigo().intValue() );
		pvaBid.setCodigoSubcapitulo( p.getSubcapitulo().getCodigo().intValue() );
		pvaBid.setCodigoDetalle( p.getDetalle() );
		pvaBid.setCodigoVariante( vp.getCodigoVariante() );
		pvaBid.setCodigoAmbito( a.getId().intValue() );

		return pvaBid;
	}

	/**
	 * @see java.lang.Object#clone()
	 */
	@Override
	public Object clone() throws CloneNotSupportedException {

		AsignacionPVAMC clon = (AsignacionPVAMC) super.clone();
		clon.setId( null );
		clon.setEstado( (AsignacionPVAModContratoEstado) clon.getEstado().clone() );
		clon.setEstadoPrevio( (AsignacionPVAModContratoEstado) clon.getEstadoPrevio().clone() );

		// clono la estructura de la PVA.

		List<AsignacionArancelPVAmbito> asgPVAAsClon = null;
		List<AsignacionArancelPVAmbito> asgPVAAs = clon.getArancelesAsignados();
		if ( ! CollectionUtils.isEmpty( asgPVAAs ) ) {
			asgPVAAsClon = new ArrayList<AsignacionArancelPVAmbito>();
			for ( AsignacionArancelPVAmbito asgPVAA: asgPVAAs ) {
				AsignacionArancelPVAmbito asgPVAAMC = (AsignacionArancelPVAmbito) asgPVAA.clone();
				asgPVAAMC.setAsginacionPVAMC( clon );

				asgPVAAsClon.add( asgPVAAMC );
			}
		}
		clon.setArancelesAsignados( asgPVAAsClon );

		List<AsignacionDiferencialServPVAmbito> asgPVADsClon = null;
		List<AsignacionDiferencialServPVAmbito> asgPVADs = clon.getDiferencialesServAsignados();
		if ( ! CollectionUtils.isEmpty( asgPVADs ) ) {
			asgPVADsClon = new ArrayList<AsignacionDiferencialServPVAmbito>();
			for ( AsignacionDiferencialServPVAmbito asgPVAD: asgPVADs ) {
				AsignacionDiferencialServPVAmbito asgPVADMC = (AsignacionDiferencialServPVAmbito) asgPVAD.clone();
				asgPVADMC.setAsginacionPVAMC( clon );

				asgPVADsClon.add( asgPVADMC );
			}
		}
		clon.setDiferencialesServAsignados( asgPVADsClon );

		return clon;
	}


	@Override
	public boolean equals( Object obj ) {
		boolean equals = false;
		if ( obj instanceof AsignacionPVAMC ) {
			AsignacionPVAMC obj1 = (AsignacionPVAMC) obj;
			if ( null != getAsignacionPVA() ) {
				equals = ( obj1.getAsignacionPVA().getId().equals( this.getAsignacionPVA().getId() ) );
			}
		}
		return equals;
	}


	@Override
	public int hashCode() {

		int hash = new HashCodeBuilder().append( this.getAsignacionPVA().getId() ).toHashCode();
		return hash;
	}

}
